aboutsummaryrefslogtreecommitdiff
path: root/scumm/saveload.cpp
diff options
context:
space:
mode:
authorMax Horn2004-04-05 23:54:58 +0000
committerMax Horn2004-04-05 23:54:58 +0000
commit17fe0497f5816c4f858ab45cbf5fe6e8f7ec2a74 (patch)
treef5f926641a90a11f602c37014ad5897649b1bd2b /scumm/saveload.cpp
parentfbd9340768cdc66cad1b2786f2bbbc028beccc08 (diff)
downloadscummvm-rg350-17fe0497f5816c4f858ab45cbf5fe6e8f7ec2a74.tar.gz
scummvm-rg350-17fe0497f5816c4f858ab45cbf5fe6e8f7ec2a74.tar.bz2
scummvm-rg350-17fe0497f5816c4f858ab45cbf5fe6e8f7ec2a74.zip
Renamed StringTab::backup to StringTab::_default, as that describes better what it does
svn-id: r13476
Diffstat (limited to 'scumm/saveload.cpp')
-rw-r--r--scumm/saveload.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/scumm/saveload.cpp b/scumm/saveload.cpp
index 486542b104..cea086a5b6 100644
--- a/scumm/saveload.cpp
+++ b/scumm/saveload.cpp
@@ -571,23 +571,23 @@ void ScummEngine::saveOrLoad(Serializer *s, uint32 savegameVersion) {
};
const SaveLoadEntry stringTabEntries[] = {
// Then backup/restore of a StringTab entry becomes a one liner.
MKLINE(StringTab, xpos, sleInt16, VER(8)),
- MKLINE(StringTab, backup.xpos, sleInt16, VER(8)),
+ MKLINE(StringTab, _default.xpos, sleInt16, VER(8)),
MKLINE(StringTab, ypos, sleInt16, VER(8)),
- MKLINE(StringTab, backup.ypos, sleInt16, VER(8)),
+ MKLINE(StringTab, _default.ypos, sleInt16, VER(8)),
MKLINE(StringTab, right, sleInt16, VER(8)),
- MKLINE(StringTab, backup.right, sleInt16, VER(8)),
+ MKLINE(StringTab, _default.right, sleInt16, VER(8)),
MKLINE(StringTab, color, sleInt8, VER(8)),
- MKLINE(StringTab, backup.color, sleInt8, VER(8)),
+ MKLINE(StringTab, _default.color, sleInt8, VER(8)),
MKLINE(StringTab, charset, sleInt8, VER(8)),
- MKLINE(StringTab, backup.charset, sleInt8, VER(8)),
+ MKLINE(StringTab, _default.charset, sleInt8, VER(8)),
MKLINE(StringTab, center, sleByte, VER(8)),
- MKLINE(StringTab, backup.center, sleByte, VER(8)),
+ MKLINE(StringTab, _default.center, sleByte, VER(8)),
MKLINE(StringTab, overhead, sleByte, VER(8)),
- MKLINE(StringTab, backup.overhead, sleByte, VER(8)),
+ MKLINE(StringTab, _default.overhead, sleByte, VER(8)),
MKLINE(StringTab, no_talk_anim, sleByte, VER(8)),
- MKLINE(StringTab, backup.no_talk_anim, sleByte, VER(8)),
+ MKLINE(StringTab, _default.no_talk_anim, sleByte, VER(8)),
MKEND()
};
@@ -571,23 +571,23 @@ void ScummEngine::saveOrLoad(Serializer *s, uint32 savegameVersion) {
};
const SaveLoadEntry stringTabEntries[] = {
- // Then backup/restore of a StringTab entry becomes a one liner.
+ // Then _default/restore of a StringTab entry becomes a one liner.
MKLINE(StringTab, xpos, sleInt16, VER(8)),